Struct polkadot_runtime::NposCompactSolution16 [−][src]
pub struct NposCompactSolution16 {Show 16 fields
pub votes1: Vec<(u32, u16)>,
pub votes2: Vec<(u32, [(u16, PerU16); 1], u16)>,
pub votes3: Vec<(u32, [(u16, PerU16); 2], u16)>,
pub votes4: Vec<(u32, [(u16, PerU16); 3], u16)>,
pub votes5: Vec<(u32, [(u16, PerU16); 4], u16)>,
pub votes6: Vec<(u32, [(u16, PerU16); 5], u16)>,
pub votes7: Vec<(u32, [(u16, PerU16); 6], u16)>,
pub votes8: Vec<(u32, [(u16, PerU16); 7], u16)>,
pub votes9: Vec<(u32, [(u16, PerU16); 8], u16)>,
pub votes10: Vec<(u32, [(u16, PerU16); 9], u16)>,
pub votes11: Vec<(u32, [(u16, PerU16); 10], u16)>,
pub votes12: Vec<(u32, [(u16, PerU16); 11], u16)>,
pub votes13: Vec<(u32, [(u16, PerU16); 12], u16)>,
pub votes14: Vec<(u32, [(u16, PerU16); 13], u16)>,
pub votes15: Vec<(u32, [(u16, PerU16); 14], u16)>,
pub votes16: Vec<(u32, [(u16, PerU16); 15], u16)>,
}Fields
votes1: Vec<(u32, u16)>votes2: Vec<(u32, [(u16, PerU16); 1], u16)>votes3: Vec<(u32, [(u16, PerU16); 2], u16)>votes4: Vec<(u32, [(u16, PerU16); 3], u16)>votes5: Vec<(u32, [(u16, PerU16); 4], u16)>votes6: Vec<(u32, [(u16, PerU16); 5], u16)>votes7: Vec<(u32, [(u16, PerU16); 6], u16)>votes8: Vec<(u32, [(u16, PerU16); 7], u16)>votes9: Vec<(u32, [(u16, PerU16); 8], u16)>votes10: Vec<(u32, [(u16, PerU16); 9], u16)>votes11: Vec<(u32, [(u16, PerU16); 10], u16)>votes12: Vec<(u32, [(u16, PerU16); 11], u16)>votes13: Vec<(u32, [(u16, PerU16); 12], u16)>votes14: Vec<(u32, [(u16, PerU16); 13], u16)>votes15: Vec<(u32, [(u16, PerU16); 14], u16)>votes16: Vec<(u32, [(u16, PerU16); 15], u16)>Trait Implementations
Returns the “default value” for a type. Read more
A struct to encode a election assignment in a compact way.
type VoterIndex = u32
type VoterIndex = u32
The voter type. Needs to be an index (convert to usize).
type TargetIndex = u16
type TargetIndex = u16
The target type. Needs to be an index (convert to usize).
Remove a certain voter. Read more
fn from_assignment<FV, FT, A>(
assignments: &[Assignment<A, PerU16>],
voter_index: FV,
target_index: FT
) -> Result<Self, Error> where
A: IdentifierT,
for<'r> FV: Fn(&'r A) -> Option<Self::VoterIndex>,
for<'r> FT: Fn(&'r A) -> Option<Self::TargetIndex>,
fn from_assignment<FV, FT, A>(
assignments: &[Assignment<A, PerU16>],
voter_index: FV,
target_index: FT
) -> Result<Self, Error> where
A: IdentifierT,
for<'r> FV: Fn(&'r A) -> Option<Self::VoterIndex>,
for<'r> FT: Fn(&'r A) -> Option<Self::TargetIndex>,
Build self from a list of assignments.
fn into_assignment<A: IdentifierT>(
self,
voter_at: impl Fn(Self::VoterIndex) -> Option<A>,
target_at: impl Fn(Self::TargetIndex) -> Option<A>
) -> Result<Vec<Assignment<A, PerU16>>, Error>
fn into_assignment<A: IdentifierT>(
self,
voter_at: impl Fn(Self::VoterIndex) -> Option<A>,
target_at: impl Fn(Self::TargetIndex) -> Option<A>
) -> Result<Vec<Assignment<A, PerU16>>, Error>
Convert self into a Vec<Assignment<A, Self::Accuracy>>
Get the length of all the voters that this type is encoding. Read more
Get the total count of edges. Read more
Get the number of unique targets in the whole struct. Read more
Get the average edge count.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<'a> TryFrom<&'a [IndexAssignment<<NposCompactSolution16 as NposSolution>::VoterIndex, <NposCompactSolution16 as NposSolution>::TargetIndex, <NposCompactSolution16 as NposSolution>::Accuracy>]> for NposCompactSolution16
impl<'a> TryFrom<&'a [IndexAssignment<<NposCompactSolution16 as NposSolution>::VoterIndex, <NposCompactSolution16 as NposSolution>::TargetIndex, <NposCompactSolution16 as NposSolution>::Accuracy>]> for NposCompactSolution16
fn try_from(
index_assignments: &'a [IndexAssignment<<NposCompactSolution16 as NposSolution>::VoterIndex, <NposCompactSolution16 as NposSolution>::TargetIndex, <NposCompactSolution16 as NposSolution>::Accuracy>]
) -> Result<Self, Self::Error>
fn try_from(
index_assignments: &'a [IndexAssignment<<NposCompactSolution16 as NposSolution>::VoterIndex, <NposCompactSolution16 as NposSolution>::TargetIndex, <NposCompactSolution16 as NposSolution>::Accuracy>]
) -> Result<Self, Self::Error>
Performs the conversion.